package org.mvcdi.component;

import javax.enterprise.inject.Default;

import org.mvcdi.api.ControllerMethodMatcher;
import org.mvcdi.metadata.ControllerInfo;
import org.mvcdi.metadata.ControllerMethod;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

@Default
public class DefaultControllerMatcher implements ControllerMethodMatcher {

	private Logger logger = LoggerFactory
			.getLogger(DefaultControllerMatcher.class);

	public ControllerMethod findMatching(ControllerInfo info,
			RequestContext context) {
		for (ControllerMethod method : info.getControllerMethods()) {
			if (matches(method, context)) {
				return method;
			}
		}
		return null;
	}

	protected boolean matches(ControllerMethod methodToTest, RequestContext context) {
		String path = context.getPath();
		boolean result = methodToTest.matchesRequestMethod(context.getRequestMethod())
				&& (methodToTest.getPrefix() == null || path.startsWith(methodToTest.getPrefix()))
				&& (methodToTest.getSuffix() == null || path.endsWith(methodToTest.getSuffix()));

		logger.debug("match result = " + result);
		return result;
	}
}
