package org.mvcdi.component;

import javax.servlet.ServletContext;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.mvcdi.annotations.RequestMethod;
import org.mvcdi.metadata.ControllerMethod;

import com.google.common.base.Preconditions;

/**
 * 
 * Everything a method could need to execute the method, return a result and use
 * that result back to the user correctly. Provides the ability to inject
 * request/response, forward to other urls, even return xml or JSON.
 * 
 * @author Andy Gibson
 */
public class RequestContext {
	
	private final ServletContext servletContext;
	private final HttpServletRequest request;
	private final HttpServletResponse response;
	private final RequestMethod requestMethod;
	private Object controller;
	private ControllerMethod method;
	private Object outcome;


	public RequestContext(ServletContext servletContext,
			HttpServletRequest request, HttpServletResponse response,
			RequestMethod requestMethod) {
		this.servletContext = servletContext;
		this.request = request;
		this.response = response;
		this.requestMethod = requestMethod;
	}

	public ServletContext getServletContext() {
		return servletContext;
	}

	public HttpServletRequest getRequest() {
		return request;
	}

	public HttpServletResponse getResponse() {
		return response;
	}

	public RequestMethod getRequestMethod() {
		return requestMethod;
	}

	public void forwardTo(String url) {
		Preconditions.checkNotNull(url);
		if (!url.startsWith("/")) {
			url = "/" + url;
		}
		try {
			servletContext.getRequestDispatcher(url).forward(request, response);
		} catch (Exception e) {
			e.printStackTrace();
		}
	}

	public String getPath() {
		return request.getPathInfo();
	}

	public Object getOutcome() {
		return outcome;
	}

	public void setOutcome(Object outcome) {
		this.outcome = outcome;
	}
	
	public ControllerMethod getMethod() {
		return method;
	}
	
	public void setMethod(ControllerMethod method) {
		this.method = method;
	}
	
	public Object getController() {
		return controller;
	}
	
	public void setController(Object controller) {
		this.controller = controller;
	}
	
}
