package org.mvcdi.metadata;

import java.lang.reflect.Method;

import org.mvcdi.annotations.RequestMethod;

public class ControllerMethod {

	private final String prefix;
	private final String suffix;
	private final RequestMethod[] requestMethod;
	private final Method method;

	public ControllerMethod(Method method, String prefix, String suffix,
			RequestMethod[] requestMethod) {
		super();
		this.prefix = prefix;
		this.suffix = suffix;
		this.method = method;
		this.requestMethod = requestMethod;
	}

	public RequestMethod[] getRequestMethod() {
		return requestMethod;
	}

	public Method getMethod() {
		return method;
	}

	public String getSuffix() {
		return suffix;
	}

	public String getPrefix() {
		return prefix;
	}

	public boolean matchesRequestMethod(RequestMethod aMethod) {
		if (requestMethod == null || requestMethod.length == 0) {
			return true;
		}
		for (RequestMethod item : requestMethod) {
			if (item ==  aMethod) {
				return true;
			}
		}
		return false;
				
	}

	@Override
	public String toString() {
		return super.toString()
				+ String.format("{prefix=%s suffix=%s reqmethod=%s method=%s",
						prefix, suffix, requestMethod, method);
	}

	public int getPathLength() {
		return (prefix == null ? 0 : prefix.length())
				+ (suffix == null ? 0 : suffix.length());
	}

	public Class<?> getControllerClass() {
		return method.getDeclaringClass();
	}

	
	public boolean getHasRequestMethod() {
		return !(requestMethod == null || requestMethod.length == 0);
	}
}
