package org.mvcdi.servlet;

import java.io.IOException;

import javax.inject.Inject;
import javax.servlet.ServletException;
import javax.servlet.annotation.WebServlet;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.mvcdi.annotations.RequestMethod;
import org.mvcdi.component.MvcHandler;
import org.mvcdi.component.RequestContext;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

@WebServlet(urlPatterns = "/demo/*")
public class DelegatingServlet extends HttpServlet {

	private static final long serialVersionUID = -3941041507536315510L;

	@Inject
	private MvcHandler mvcHandler;

	private static final Logger logger = LoggerFactory
			.getLogger(DelegatingServlet.class);

	@Override
	protected void doGet(HttpServletRequest req, HttpServletResponse resp)
			throws ServletException, IOException {
		doHandleRequest(req, resp, RequestMethod.GET);
	}

	@Override
	protected void doPost(HttpServletRequest req, HttpServletResponse resp)
			throws ServletException, IOException {
		doHandleRequest(req, resp, RequestMethod.POST);
	}

	public void doHandleRequest(HttpServletRequest request,
			HttpServletResponse response, RequestMethod requestMethod) {
		
		RequestContext context = new RequestContext(getServletContext(),
				request, response, requestMethod);
		logger.debug("Servlet delegating the {} request from {}",
				requestMethod, request.getRequestURI());
		mvcHandler.handleRequest(context);
	}

}